Errata

Struct Errata 

pub struct Errata {
    pub type0_legacy_server: bool,
    pub type0_legacy_server_box: bool,
    pub core_record_size_bytes: bool,
}
Collection of Intel Crash Log erratas

Fields

type0_legacy_server: bool

Type0 server legacy header

Some Intel(R) products in the server segment are using legacy Crash Log record headers with Type0, which has a different layout compared with the currently defined Type0 Header.

type0_legacy_server_box: bool

Type0 server legacy header box record

Some Intel(R) products in the server segment that are using the legacy Crash Log record header with Type0 are using the PCORE record type with the same functionality as a BOX record.

core_record_size_bytes: bool

Core record using record size in bytes

The Crash Log headers have their sizes in DWORDs, but for some products that are using ECORE and PCORE Crash Log records, their sizes are written in bytes.

Implementations

Source

impl Errata

pub fn from_version(version: &Version) -> Self